using System.Collections.Generic;
using BeginningtoMock.Part2.Business;
using BeginningtoMock.Part2.Data;
using MbUnit.Framework;
using Rhino.Mocks;
using System.Data;
using System;

namespace BeginningtoMock.Part2.Tests
{
    [TestFixture]
    public class BooksDataAccessTests
    {
        internal DataTable CreateDataTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("id", typeof(int));
            dt.Columns.Add("Title", typeof(string));
            dt.Columns.Add("Price", typeof(double));

            DataRow dr = dt.NewRow();
            dr[0] = 1;
            dr[1] = "Test";
            dr[2] = 10.12;

            dt.Rows.Add(dr);

            return dt;
        }

        [Test]
        public void ConstructorAcceptsISqlDatabase()
        {
            ISqlDatabase database = new SqlDatabase("");

            BooksDataAccess da = new BooksDataAccess(database);

            Assert.IsNotNull(da.database);
        }

        [Test]
        public void GetAllBooksExecutesAndReturnsBooks()
        {
            MockRepository mocks = new MockRepository();
            ISqlDatabase mockDatabase = mocks.CreateMock<ISqlDatabase>();

            DataTable dt = CreateDataTable();

            string sqlStatement = "SELECT * FROM Books";

            using(mocks.Record())
            {
                mockDatabase.CreateConnection();
                
                Expect.Call(mockDatabase.ExecuteReader(CommandType.Text, sqlStatement)).Return(dt);
            }

            using (mocks.Playback())
            {
                BooksDataAccess da = new BooksDataAccess(mockDatabase);
                List<Book> books = da.GetAllBooks();
                Assert.IsNotNull(books, "Books response is null");
                Assert.AreEqual(1, books.Count);
            }
        }

        [Test]
        public void GetAllBooksSqlReturnsExpectedTSQL()
        {
            BooksDataAccess da = new BooksDataAccess(null);
            string sqlStatement = "SELECT * FROM Books";
            Assert.AreEqual(sqlStatement, da.GetAllBooksSql());
        }

        [Test]
        public void CanCreateAGenericListOfBooksFromDataTable()
        {
            DataTable dt = CreateDataTable();
            BooksDataAccess da = new BooksDataAccess(null);
            List<Book> books = da.CreateBookListFromDataTable(dt);
            Assert.IsNotNull(books, "Book list is null");
            Assert.AreEqual(1, books.Count);
            Book bookReturned = books[0];
            Assert.AreEqual(bookReturned.ID, 1);
            Assert.AreEqual(bookReturned.Title, "Test");
            Assert.AreEqual(bookReturned.Price, 10.12);
        }
    }
}
