using System;
using System.Data;
using MbUnit.Framework;
using BeginningtoMock.Part2.Data;


namespace BeginningtoMock.Part2.Tests
{
    [TestFixture]
    public class SqlDatabaseTests
    {
        private string connectionString = "Data Source=.;Initial Catalog=master;Integrated Security=True";

        [Test]
        public void SqlDatabaseConstructorPopulatesConnectionString()
        {
            SqlDatabase sqlDb = new SqlDatabase(connectionString);
            Assert.AreEqual(connectionString, sqlDb.ConnectionString, "Connection string does not match constructor connection string");
        }

        [Test]
        public void CreateConnectionCreatesASqlConnection()
        {
            SqlDatabase sqlDb = new SqlDatabase(connectionString);

            sqlDb.CreateConnection();
            Assert.IsInstanceOfType(typeof(System.Data.SqlClient.SqlConnection), sqlDb.Connection, "Connection is not of type SqlConnection");
        }

        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void CannotCreateConnectionWithoutConnectionString()
        {
            SqlDatabase newSqlDb = new SqlDatabase("");
            newSqlDb.CreateConnection();
        }

        [Test]
        public void ConnectionStringSetterSetsVariable()
        {
            SqlDatabase sqlDb = new SqlDatabase(connectionString);

            string connStr = "server=Can be anything";
            sqlDb.SetConnectionString(connStr);
            Assert.AreEqual(connStr, sqlDb.ConnectionString);
        }

        [Test]
        public void ExecuteCommandAgainstServer()
        {
            SqlDatabase sqlDb = new SqlDatabase(connectionString);
            sqlDb.CreateConnection();
            DataTable dataTable = sqlDb.ExecuteReader(CommandType.Text, "use master; select * from sys.databases;");
            Assert.IsNotNull(dataTable);

            Assert.GreaterEqualThan(dataTable.Rows.Count, 1, "No records returned");

        }
    }
}
