using BeginningtoMock.Part2.Data.WebService;
using MbUnit.Framework;
using Rhino.Mocks;

namespace BeginningtoMock.Part2.Tests
{
    [TestFixture]
    public class WebServiceTests
    {
        [Test]
        public void ProxyCanBeSetAsAParameter()
        {
            PaymentProcessingProxy proxy = new PaymentProcessingProxy();
            PaymentProcessor pp = new PaymentProcessor(proxy);
            Assert.IsNotNull(pp.wsProxy);
        }

        [Test]
        public void TakePaymentViaPaymentProcessorUsingMockService()
        {
            MockRepository mocks = new MockRepository();
            IPaymentProcessing mockProxy = mocks.CreateMock<IPaymentProcessing>();

            using(mocks.Record())
            {
                Expect.Call(mockProxy.TakePayment(1, 1, 10.0)).IgnoreArguments().Return(true);
            }

            using(mocks.Playback())
            {
                PaymentProcessor pp = new PaymentProcessor(mockProxy);
                bool result = pp.TakePayment(1, 1, 10.0);
                Assert.IsTrue(result);
            }
        }

        [Test]
        public void PaymentProcessorProxyExecutesCorrectlyUsingRealService()
        {
            PaymentProcessingProxy proxy = new PaymentProcessingProxy();
            bool result = proxy.TakePayment(1, 1, 10.0);
            Assert.IsTrue(result);
        }
    }
}
