using System;
using System.Data.SqlClient;
using System.Data;

namespace BeginningtoMock.Part2.Data
{
    public class SqlDatabase : ISqlDatabase
    {
        private SqlConnection connection;
        private string connectionString;

        public SqlDatabase(string connection)
        {
            connectionString = connection;
        }

        public IDbConnection Connection
        {
            get { return connection; }
        }

        public string ConnectionString
        {
            get { return connectionString; }
        }

        public void CreateConnection()
        {
            if(string.IsNullOrEmpty(connectionString))
                throw new ArgumentNullException("ConnectionString", "Must populate connection string first");

            connection = new SqlConnection(connectionString);
        }

        public DataTable ExecuteReader(CommandType type, string sql)
        {
            DataTable dt = new DataTable();
            try
            {
                IDbCommand cmd = Connection.CreateCommand();
                cmd.CommandType = type;
                cmd.CommandText = sql;

                Connection.Open();

                IDataReader dr = cmd.ExecuteReader();
                dt.Load(dr);
            }
            finally
            {
                if (Connection.State != ConnectionState.Closed)
                    Connection.Close();
            }

            return dt;
        }

        public void SetConnectionString(string connString)
        {
            connectionString = connString;
        }
    }
}
